[kaffe] CVS kaffe (dalibor): Fixed compiler warnings where daemon overshadowed system declaration

Kaffe CVS cvs-commits at kaffe.org
Wed Mar 24 13:58:02 PST 2004


PatchSet 4576 
Date: 2004/03/24 21:44:32
Author: dalibor
Branch: HEAD
Tag: (none) 
Log:
Fixed compiler warnings where daemon overshadowed system declaration

2004-03-24  Dalibor Topic <robilad at kaffe.org>

        * kaffe/kaffevm/systems/unix-pthreads/thread-internal.h
        (jthread_attach_current_thread): Renamed daemon to is_daemon
        to fix compiler warnings.

Members: 
	ChangeLog:1.2154->1.2155 
	kaffe/kaffevm/systems/unix-pthreads/thread-internal.h:1.11->1.12 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.2154 kaffe/ChangeLog:1.2155
--- kaffe/ChangeLog:1.2154	Wed Mar 24 21:22:04 2004
+++ kaffe/ChangeLog	Wed Mar 24 21:44:32 2004
@@ -1,5 +1,11 @@
 2004-03-24  Dalibor Topic <robilad at kaffe.org>
 
+	* kaffe/kaffevm/systems/unix-pthreads/thread-internal.h
+	(jthread_attach_current_thread): Renamed daemon to is_daemon
+	to fix compiler warnings.
+
+2004-03-24  Dalibor Topic <robilad at kaffe.org>
+
 	* kaffe/kaffevm/gc.h:
 	(GarbageCollectorInterface_Ops) Renamed index to gc_index 
 	to fix compiler warnings.
Index: kaffe/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h
diff -u kaffe/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h:1.11 kaffe/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h:1.12
--- kaffe/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h:1.11	Sun Feb  1 22:14:55 2004
+++ kaffe/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h	Wed Mar 24 21:44:34 2004
@@ -86,10 +86,10 @@
 /**
  * Attaches the calling thread to the vm.
  *
  * @param daemon wether the thread is to be treated as a daemon thread
  *
  */
-bool jthread_attach_current_thread (bool daemon);
+bool jthread_attach_current_thread (bool is_daemon);
 
 void jthread_sleep (jlong timeout);
 
@@ -337,7 +337,7 @@
  * Create a new native thread.
  *
  */
-jthread_t jthread_create (unsigned char pri, void* func, int daemon,
+jthread_t jthread_create (unsigned char pri, void* func, int is_daemon,
 			  void* jlThread, size_t threadStackSize );
 
 
@@ -86,10 +86,10 @@
  * Attaches the calling thread to the vm.
  *
- * @param daemon wether the thread is to be treated as a daemon thread
+ * @param is_daemon wether the thread is to be treated as a daemon thread
  *
  */




More information about the kaffe mailing list